@@ -24,8 +24,15 @@
 
 #include <gtk/gtkwidget.h>
 
+#define DSN_PAGE      "DSN_Page"
+#define PROVIDER_PAGE "Provider_Page"
+
 GtkWidget *database_capplet_new (void);
 void       database_capplet_edit_properties (GtkWidget *capplet);
 void       database_capplet_delete (GtkWidget *capplet);
+void       database_capplet_select_all (GtkWidget *capplet);
+void       database_capplet_deselect_all (GtkWidget *capplet);
+gboolean   database_capplet_has_selection (GtkWidget *capplet);
+void       database_capplet_switch (GtkWidget *capplet, const gchar *page);
 
 #endif
