@@ -25,7 +25,7 @@
 #include <libgnomedb/gnome-db-browser.h>
 #include <libgnomedb/gnome-db-grid.h>
 #include <libgnomedb/gnome-db-util.h>
-#include <bonobo/bonobo-i18n.h>
+#include "gnome-db-i18n.h"
 #include "gnome-db-browser-private.h"
 
 typedef struct {
