@@ -242,6 +242,7 @@ gnome_db_config_get_component_data_model (const gchar *query)
 
 /**
  * gnome_db_config_free_component_list
+ * @list:
  */
 void
 gnome_db_config_free_component_list (GList *list)
@@ -282,7 +283,11 @@ sync_from_gda ()
 	gchar *epath;
 	gchar *type;
 	gchar *str;
-	
+
+	/* clear the previous data sources */
+	gnome_db_config_remove_section (GDA_CONFIG_SECTION_DATASOURCES);
+
+	/* add all data sources from the libgda configuration */
 	sections = gda_config_list_sections (GDA_CONFIG_BASE);
 	for (s = sections; s; s = s->next){
 		spath = g_strdup_printf ("%s/%s", GDA_CONFIG_BASE,
@@ -330,8 +335,11 @@ sync_to_gda (GConfClient *client,
 
 	key = gconf_entry_get_key (entry);
 	value = gconf_entry_get_value (entry);
-	if (value == NULL){
-		gda_config_remove_key (key);
+	if (value == NULL) {
+		if (gda_config_has_section (key))
+			gda_config_remove_section (key);
+		else
+			gda_config_remove_key (key);
 		return;
 	}
 
@@ -488,20 +496,9 @@ gnome_db_config_set_boolean (const gchar * path, gboolean new_value)
 void
 gnome_db_config_remove_section (const gchar * path)
 {
-	GSList *slist, *iter;
-	const gchar *key;
 	g_return_if_fail (path != NULL);
 	
-	slist = gconf_client_all_entries (get_conf_client (), path, NULL);
-	for (iter = slist; iter != NULL; iter = iter->next) {
-		GConfEntry *entry = iter->data;
-		
-		key = gconf_entry_get_key (entry);
-		gconf_client_unset (get_conf_client (), key, NULL);
-		gconf_entry_free (entry);
-	}
-	g_slist_free (slist);
-		
+	gconf_client_recursive_unset (get_conf_client (), path, 0, NULL);	
 }
 
 /**
@@ -867,6 +864,7 @@ gnome_db_config_remove_data_source (const gchar *name)
 
 	dir = g_strdup_printf ("%s/%s", GDA_CONFIG_SECTION_DATASOURCES, name);
 	gnome_db_config_remove_section (dir);
+	gda_config_remove_section (dir);
 	g_free (dir);
 }
 
