@@ -45,6 +45,9 @@ struct _GnomeDbDsnConfig {
 
 struct _GnomeDbDsnConfigClass {
 	GtkVBoxClass parent_class;
+
+	/* signals */
+	void (* changed) (GnomeDbDsnConfig *config);
 };
 
 GType              gnome_db_dsn_config_get_type (void);
