@@ -20,6 +20,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include <gtk/gtkimage.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtkstock.h>
 #include <gtk/gtktable.h>
@@ -30,6 +31,9 @@
 #include <libgnomedb/gnome-db-util.h>
 #include "gnome-db-i18n.h"
 
+extern void gnome_db_stock_init (void);
+
+
 struct _GnomeDbLoginDialogPrivate {
 	GtkWidget *login;
 };
@@ -121,6 +125,7 @@ gnome_db_login_dialog_init (GnomeDbLoginDialog *dialog, GnomeDbLoginDialogClass
 					     "to a data source"));
 	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
         gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+	gtk_label_set_selectable (GTK_LABEL (label), FALSE);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
 	gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
 
@@ -219,6 +224,11 @@ gnome_db_login_dialog_get_type (void)
 
 /**
  * gnome_db_login_dialog_new
+ * @title:
+ *
+ *
+ *
+ * Returns:
  */
 GtkWidget *
 gnome_db_login_dialog_new (const gchar *title)
@@ -240,6 +250,11 @@ gnome_db_login_dialog_new (const gchar *title)
 
 /**
  * gnome_db_login_dialog_run
+ * @dialog:
+ *
+ *
+ *
+ * Returns:
  */
 gboolean
 gnome_db_login_dialog_run (GnomeDbLoginDialog *dialog)
@@ -254,6 +269,11 @@ gnome_db_login_dialog_run (GnomeDbLoginDialog *dialog)
 
 /**
  * gnome_db_login_dialog_get_dsn
+ * @dialog:
+ *
+ *
+ *
+ * Returns:
  */
 const gchar *gnome_db_login_dialog_get_dsn (GnomeDbLoginDialog *dialog)
 {
@@ -263,6 +283,11 @@ const gchar *gnome_db_login_dialog_get_dsn (GnomeDbLoginDialog *dialog)
 
 /**
  * gnome_db_login_dialog_get_username
+ * @dialog:
+ *
+ *
+ *
+ * Returns:
  */
 const gchar *gnome_db_login_dialog_get_username (GnomeDbLoginDialog *dialog)
 {
@@ -272,6 +297,11 @@ const gchar *gnome_db_login_dialog_get_username (GnomeDbLoginDialog *dialog)
 
 /**
  * gnome_db_login_dialog_get_password
+ * @dialog:
+ *
+ *
+ *
+ * Returns:
  */
 const gchar *gnome_db_login_dialog_get_password (GnomeDbLoginDialog *dialog)
 {
