@@ -26,6 +26,7 @@
 #include <glib-object.h>
 #include <gtk/gtkbutton.h>
 #include <gtk/gtkcheckbutton.h>
+#include <gtk/gtkcheckmenuitem.h>
 #include <gtk/gtkcombo.h>
 #include <gtk/gtkfilesel.h>
 #include <gtk/gtkframe.h>
@@ -33,21 +34,28 @@
 #include <gtk/gtkhbox.h>
 #include <gtk/gtkhpaned.h>
 #include <gtk/gtkhseparator.h>
+#include <gtk/gtkimage.h>
+#include <gtk/gtkimagemenuitem.h>
 #include <gtk/gtklabel.h>
-#include <gtk/gtkmenu.h>
 #include <gtk/gtkmain.h>
+#include <gtk/gtkmenu.h>
 #include <gtk/gtkmenuitem.h>
 #include <gtk/gtkmenushell.h>
 #include <gtk/gtkmessagedialog.h>
 #include <gtk/gtknotebook.h>
 #include <gtk/gtkradiobutton.h>
 #include <gtk/gtkscrolledwindow.h>
+#include <gtk/gtkseparatormenuitem.h>
 #include <gtk/gtkstatusbar.h>
 #include <gtk/gtkstock.h>
 #include <gtk/gtktable.h>
 #include <gtk/gtktextbuffer.h>
 #include <gtk/gtktreeview.h>
 #include <gtk/gtkvbox.h>
+#include <gtk/gtkversion.h>
+#if GTK_CHECK_VERSION(2, 4, 0)
+#  include <gtk/gtkfilechooserdialog.h>
+#endif
 #include <gtk/gtkvpaned.h>
 #include <gtk/gtkvseparator.h>
 #include <gtk/gtkwindow.h>
@@ -63,6 +71,10 @@
 
 /**
  * gnome_db_new_browser_widget
+ *
+ *
+ *
+ * Returns:
  */
 #ifdef BUILD_WITH_GNOME
 GtkWidget *
@@ -79,6 +91,11 @@ gnome_db_new_browser_widget (void)
 
 /**
  * gnome_db_new_button_widget
+ * @label:
+ *
+ *
+ *
+ * Returns:
  */
 GtkWidget *
 gnome_db_new_button_widget (const gchar *label)
@@ -96,6 +113,11 @@ gnome_db_new_button_widget (const gchar *label)
 
 /**
  * gnome_db_new_button_widget_from_stock
+ * @stock_id:
+ *
+ *
+ *
+ * Returns:
  */
 GtkWidget *
 gnome_db_new_button_widget_from_stock (const gchar *stock_id)
@@ -110,6 +132,11 @@ gnome_db_new_button_widget_from_stock (const gchar *stock_id)
 
 /**
  * gnome_db_new_check_button_widget
+ * @label:
+ *
+ *
+ *
+ * Returns:
  */
 GtkWidget *
 gnome_db_new_check_button_widget (const gchar *label)
@@ -127,6 +154,10 @@ gnome_db_new_check_button_widget (const gchar *label)
 
 /**
  * gnome_db_new_combo_widget
+ *
+ *
+ *
+ * Returns:
  */
 GtkWidget *
 gnome_db_new_combo_widget (void)
@@ -141,6 +172,12 @@ gnome_db_new_combo_widget (void)
 
 /**
  * gnome_db_new_entry_widget
+ * @max_length:
+ * @editable:
+ *
+ *
+ *
+ * Returns:
  */
 GtkWidget *
 gnome_db_new_entry_widget (gint max_length, gboolean editable)
@@ -159,13 +196,28 @@ gnome_db_new_entry_widget (gint max_length, gboolean editable)
 #ifdef BUILD_WITH_GNOME
 /**
  * gnome_db_new_file_entry_widget
+ * @history_id:
+ * @title:
+ *
+ *
+ *
+ * Returns:
  */
 GtkWidget *
 gnome_db_new_file_entry_widget (const gchar *history_id, const gchar *title)
 {
 	GtkWidget *entry;
+#if GTK_CHECK_VERSION(2,4,0)
+	GValue value = { 0, };
+#endif
 
 	entry = gnome_file_entry_new (history_id, title);
+#if GTK_CHECK_VERSION(2, 4, 0)
+	g_value_init (&value, G_TYPE_BOOLEAN);
+	g_value_set_boolean (&value, TRUE);
+	g_object_set_property (G_OBJECT (entry), "use-filechooser", &value);
+	g_value_reset (&value);
+#endif
 	gtk_widget_show (entry);
 
 	return entry;
@@ -174,6 +226,11 @@ gnome_db_new_file_entry_widget (const gchar *history_id, const gchar *title)
 
 /**
  * gnome_db_new_frame_widget
+ * @title:
+ *
+ *
+ *
+ * Returns:
  */
 GtkWidget *
 gnome_db_new_frame_widget (const gchar *title)
@@ -188,6 +245,11 @@ gnome_db_new_frame_widget (const gchar *title)
 
 /**
  * gnome_db_new_grid_widget
+ * @model:
+ *
+ *
+ *
+ * Returns:
  */
 GtkWidget *
 gnome_db_new_grid_widget (GdaDataModel *model)
@@ -205,6 +267,12 @@ gnome_db_new_grid_widget (GdaDataModel *model)
 
 /**
  * gnome_db_new_hbox_widget
+ * @homogenous:
+ * @spacing:
+ *
+ *
+ *
+ * Returns:
  */
 GtkWidget *
 gnome_db_new_hbox_widget (gboolean homogenous, gint spacing)
@@ -219,6 +287,10 @@ gnome_db_new_hbox_widget (gboolean homogenous, gint spacing)
 
 /**
  * gnome_db_new_hbutton_box_widget
+ *
+ *
+ *
+ * Returns: 
  */
 GtkWidget *
 gnome_db_new_hbutton_box_widget (void)
@@ -233,6 +305,10 @@ gnome_db_new_hbutton_box_widget (void)
 
 /**
  * gnome_db_new_hpaned_widget
+ *
+ *
+ *
+ * Returns:
  */
 GtkWidget *
 gnome_db_new_hpaned_widget (void)
@@ -247,6 +323,10 @@ gnome_db_new_hpaned_widget (void)
 
 /**
  * gnome_db_new_hseparator_widget
+ *
+ *
+ *
+ * Returns:
  */
 GtkWidget *
 gnome_db_new_hseparator_widget (void)
@@ -261,13 +341,18 @@ gnome_db_new_hseparator_widget (void)
 
 /**
  * gnome_db_new_label_widget
+ * @text:
+ *
+ *
+ *
+ * Returns:
  */
 GtkWidget *
 gnome_db_new_label_widget (const gchar *text)
 {
 	GtkWidget *label;
 
-	label = gtk_label_new (text);
+	label = gtk_label_new_with_mnemonic (text);
 	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_widget_show (label);
@@ -277,6 +362,10 @@ gnome_db_new_label_widget (const gchar *text)
 
 /**
  * gnome_db_new_notebook_widget
+ *
+ *
+ *
+ * Returns:
  */
 GtkWidget *
 gnome_db_new_notebook_widget (void)
@@ -294,6 +383,10 @@ gnome_db_new_notebook_widget (void)
 
 /**
  * gnome_db_new_option_menu_widget
+ *
+ *
+ *
+ * Returns:
  */
 GtkWidget *
 gnome_db_new_option_menu_widget (void)
@@ -309,6 +402,13 @@ gnome_db_new_option_menu_widget (void)
 #ifdef BUILD_WITH_GNOME
 /**
  * gnome_db_new_popup_menu
+ * @parent:
+ * @ui_info:
+ * @user_data:
+ *
+ *
+ *
+ * Returns:
  */
 GtkWidget *
 gnome_db_new_popup_menu (GtkWidget *parent, GnomeUIInfo *ui_info, gpointer user_data)
@@ -327,6 +427,12 @@ gnome_db_new_popup_menu (GtkWidget *parent, GnomeUIInfo *ui_info, gpointer user_
 
 /**
  * gnome_db_new_radio_button_widget
+ * @group:
+ * @label:
+ *
+ *
+ *
+ * Returns:
  */
 GtkWidget *
 gnome_db_new_radio_button_widget (GSList *group, const gchar *label)
@@ -341,6 +447,10 @@ gnome_db_new_radio_button_widget (GSList *group, const gchar *label)
 
 /**
  * gnome_db_new_scrolled_window_widget
+ *
+ *
+ *
+ * Returns:
  */
 GtkWidget *
 gnome_db_new_scrolled_window_widget (void)
@@ -360,6 +470,10 @@ gnome_db_new_scrolled_window_widget (void)
 
 /**
  * gnome_db_new_status_bar_widget
+ *
+ *
+ *
+ * Returns:
  */
 GtkWidget *
 gnome_db_new_status_bar_widget (void)
@@ -374,6 +488,13 @@ gnome_db_new_status_bar_widget (void)
 
 /**
  * gnome_db_new_table_widget
+ * @rows:
+ * @cols:
+ * @homogenous:
+ *
+ *
+ *
+ * Returns:
  */
 GtkWidget *
 gnome_db_new_table_widget (gint rows, gint cols, gboolean homogenous)
@@ -391,6 +512,11 @@ gnome_db_new_table_widget (gint rows, gint cols, gboolean homogenous)
 
 /**
  * gnome_db_new_text_widget
+ * @contents:
+ *
+ *
+ *
+ * Returns:
  */
 GtkWidget *
 gnome_db_new_text_widget (const gchar *contents)
@@ -414,6 +540,12 @@ gnome_db_new_text_widget (const gchar *contents)
 
 /**
  * gnome_db_new_toolbar_widget
+ * @orientation:
+ * @style:
+ *
+ *
+ *
+ * Returns:
  */
 GtkWidget *
 gnome_db_new_toolbar_widget (GtkOrientation orientation, GtkToolbarStyle style)
@@ -430,6 +562,11 @@ gnome_db_new_toolbar_widget (GtkOrientation orientation, GtkToolbarStyle style)
 
 /**
  * gnome_db_new_tree_view_widget
+ * @model:
+ *
+ *
+ *
+ * Returns:
  */
 GtkWidget *
 gnome_db_new_tree_view_widget (GtkTreeModel *model)
@@ -447,6 +584,12 @@ gnome_db_new_tree_view_widget (GtkTreeModel *model)
 
 /**
  * gnome_db_new_vbox_widget
+ * @homogenous:
+ * @spacing:
+ *
+ *
+ *
+ * Returns:
  */
 GtkWidget *
 gnome_db_new_vbox_widget (gboolean homogenous, gint spacing)
@@ -461,6 +604,10 @@ gnome_db_new_vbox_widget (gboolean homogenous, gint spacing)
 
 /**
  * gnome_db_new_vpaned_widget
+ *
+ *
+ *
+ * Returns:
  */
 GtkWidget *
 gnome_db_new_vpaned_widget (void)
@@ -475,6 +622,10 @@ gnome_db_new_vpaned_widget (void)
 
 /**
  * gnome_db_new_vseparator_widget
+ *
+ *
+ *
+ * Returns:
  */
 GtkWidget *
 gnome_db_new_vseparator_widget (void)
@@ -489,6 +640,9 @@ gnome_db_new_vseparator_widget (void)
 
 /**
  * gnome_db_set_widget_bg_color
+ * @widget:
+ * @color:
+ *
  */
 void
 gnome_db_set_widget_bg_color (GtkWidget *widget, const gchar *color)
@@ -503,6 +657,9 @@ gnome_db_set_widget_bg_color (GtkWidget *widget, const gchar *color)
 
 /**
  * gnome_db_set_widget_fg_color
+ * @widget:
+ * @color:
+ *
  */
 void
 gnome_db_set_widget_fg_color (GtkWidget *widget, const gchar *color)
@@ -517,15 +674,21 @@ gnome_db_set_widget_fg_color (GtkWidget *widget, const gchar *color)
 
 /**
  * gnome_db_option_menu_add_item
+ * @option_menu:
+ * @label:
+ *
+ *
+ *
+ * Returns:
  */
-void
+GtkWidget *
 gnome_db_option_menu_add_item (GtkOptionMenu *option_menu, const gchar *label)
 {
 	GtkWidget *menu;
 	GtkWidget *menu_item;
 
-	g_return_if_fail (GTK_IS_OPTION_MENU (option_menu));
-	g_return_if_fail (label != NULL);
+	g_return_val_if_fail (GTK_IS_OPTION_MENU (option_menu), NULL);
+	g_return_val_if_fail (label != NULL, NULL);
 
 	menu = gtk_option_menu_get_menu (option_menu);
 	if (!GTK_IS_MENU (menu)) {
@@ -540,19 +703,90 @@ gnome_db_option_menu_add_item (GtkOptionMenu *option_menu, const gchar *label)
 				g_strdup (label), (GDestroyNotify) g_free);
 
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
+
+	return menu_item;
+}
+
+/**
+ * gnome_db_option_menu_add_stock_item
+ * @option_menu:
+ * @stock_id:
+ *
+ *
+ *
+ * Returns:
+ */
+GtkWidget *
+gnome_db_option_menu_add_stock_item (GtkOptionMenu *option_menu, const gchar *stock_id)
+{
+	GtkWidget *menu;
+	GtkWidget *menu_item;
+
+	g_return_val_if_fail (GTK_IS_OPTION_MENU (option_menu), NULL);
+	g_return_val_if_fail (stock_id != NULL, NULL);
+
+	menu = gtk_option_menu_get_menu (option_menu);
+	if (!GTK_IS_MENU (menu)) {
+		menu = gtk_menu_new ();
+		gtk_option_menu_set_menu (option_menu, menu);
+		gtk_widget_show (menu);
+	}
+
+	menu_item = gtk_image_menu_item_new_from_stock (stock_id, NULL);
+	gtk_widget_show (menu_item);
+	g_object_set_data_full (G_OBJECT (menu_item), "GNOME:Database:MenuItemLabel",
+				g_strdup (stock_id), (GDestroyNotify) g_free);
+
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
+
+	return menu_item;
+}
+
+/**
+ * gnome_db_option_menu_add_separator
+ * @option_menu:
+ *
+ */
+void
+gnome_db_option_menu_add_separator (GtkOptionMenu *option_menu)
+{
+	GtkWidget *menu;
+	GtkWidget *menu_item;
+
+	g_return_if_fail (GTK_IS_OPTION_MENU (option_menu));
+
+	menu = gtk_option_menu_get_menu (option_menu);
+	if (!GTK_IS_MENU (menu)) {
+		menu = gtk_menu_new ();
+		gtk_option_menu_set_menu (option_menu, menu);
+		gtk_widget_show (menu);
+	}
+
+	menu_item = gtk_separator_menu_item_new ();
+	gtk_widget_show (menu_item);
+
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
 }
 
 /**
  * gnome_db_option_menu_get_selection
+ * @option_menu:
+ *
+ *
+ *
+ * Returns:
  */
 const gchar *
 gnome_db_option_menu_get_selection (GtkOptionMenu *option_menu)
 {
 	GtkWidget *menu_item;
+	GtkWidget *menu;
 
 	g_return_val_if_fail (GTK_IS_OPTION_MENU (option_menu), NULL);
 
-	menu_item = option_menu->menu_item;
+	menu = gtk_option_menu_get_menu(option_menu);
+	menu_item = gtk_menu_get_active(menu);
+
 	if (GTK_IS_MENU_ITEM (menu_item)) {
 		return (const gchar *) g_object_get_data (G_OBJECT (menu_item),
 							  "GNOME:Database:MenuItemLabel");
@@ -563,6 +797,9 @@ gnome_db_option_menu_get_selection (GtkOptionMenu *option_menu)
 
 /**
  * gnome_db_option_menu_set_selection
+ * @option_menu:
+ * @selection:
+ *
  */
 void
 gnome_db_option_menu_set_selection (GtkOptionMenu *option_menu, const gchar *selection)
@@ -575,6 +812,8 @@ gnome_db_option_menu_set_selection (GtkOptionMenu *option_menu, const gchar *sel
 	g_return_if_fail (selection != NULL);
 
 	menu = gtk_option_menu_get_menu (option_menu);
+	if (!GTK_IS_MENU_SHELL (menu))
+		return;
 
 	for (l = GTK_MENU_SHELL (menu)->children, i = 0; l != NULL; l = l->next, i++) {
 		const gchar *str;
@@ -616,6 +855,7 @@ gnome_db_text_clear (GtkTextView *text)
 
 /**
  * gnome_db_text_copy_clipboard
+ * @text:
  */
 void
 gnome_db_text_copy_clipboard (GtkTextView *text)
@@ -627,6 +867,8 @@ gnome_db_text_copy_clipboard (GtkTextView *text)
 
 /**
  * gnome_db_text_cut_clipboard
+ * @text:
+ *
  */
 void
 gnome_db_text_cut_clipboard (GtkTextView *text)
@@ -639,6 +881,11 @@ gnome_db_text_cut_clipboard (GtkTextView *text)
 
 /**
  * gnome_db_text_get_char_count
+ * @text:
+ *
+ *
+ *
+ * Returns:
  */
 gint
 gnome_db_text_get_char_count (GtkTextView *text)
@@ -649,6 +896,11 @@ gnome_db_text_get_char_count (GtkTextView *text)
 
 /**
  * gnome_db_text_get_line_count
+ * @text:
+ *
+ *
+ *
+ * Returns:
  */
 gint
 gnome_db_text_get_line_count (GtkTextView *text)
@@ -659,6 +911,11 @@ gnome_db_text_get_line_count (GtkTextView *text)
 
 /**
  * gnome_db_text_get_text
+ * @text:
+ *
+ *
+ *
+ * Returns:
  */
 gchar *
 gnome_db_text_get_text (GtkTextView *text)
@@ -682,6 +939,9 @@ gnome_db_text_get_text (GtkTextView *text)
 
 /**
  * gnome_db_text_insert_at_cursor
+ * @text:
+ * @contents:
+ * @len:
  */
 void
 gnome_db_text_insert_at_cursor (GtkTextView *text, const gchar *contents, gint len)
@@ -694,6 +954,7 @@ gnome_db_text_insert_at_cursor (GtkTextView *text, const gchar *contents, gint l
 
 /**
  * gnome_db_text_paste_clipboard
+ * @text:
  */
 void
 gnome_db_text_paste_clipboard (GtkTextView *text)
@@ -707,6 +968,10 @@ gnome_db_text_paste_clipboard (GtkTextView *text)
 
 /**
  * gnome_db_text_set_text
+ * @text:
+ * @contents:
+ * @len:
+ *
  */
 void
 gnome_db_text_set_text (GtkTextView *text, const gchar *contents, gint len)
@@ -717,6 +982,12 @@ gnome_db_text_set_text (GtkTextView *text, const gchar *contents, gint len)
 
 /**
  * gnome_db_select_file_dialog
+ * @parent:
+ * @title:
+ *
+ *
+ *
+ * Returns:
  */
 gchar *
 gnome_db_select_file_dialog (GtkWidget *parent, const gchar *title)
@@ -724,6 +995,13 @@ gnome_db_select_file_dialog (GtkWidget *parent, const gchar *title)
 	GtkWidget *filesel;
         gchar *res = NULL;
 
+#if GTK_CHECK_VERSION(2,4,0)
+	/* create dialog */
+	filesel = gtk_file_chooser_dialog_new (title, parent, GTK_FILE_CHOOSER_ACTION_SAVE,
+					       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					       GTK_STOCK_OK, GTK_RESPONSE_OK,
+					       NULL);
+#else
         /* create dialog */
         filesel = gtk_file_selection_new (title);
 	if (GTK_IS_WINDOW (parent)) {
@@ -731,10 +1009,17 @@ gnome_db_select_file_dialog (GtkWidget *parent, const gchar *title)
 				              GTK_WINDOW (parent));
 	}
         gtk_file_selection_show_fileop_buttons (GTK_FILE_SELECTION (filesel));
+#endif
+
+	gtk_dialog_set_default_response (GTK_DIALOG (filesel), GTK_RESPONSE_OK);
 
         /* wait for selection from user */
 	if (gtk_dialog_run (GTK_DIALOG (filesel)) == GTK_RESPONSE_OK)
+#if GTK_CHECK_VERSION(2, 4, 0)
+		res = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (filesel));
+#else
 		res = g_strdup (gtk_file_selection_get_filename (GTK_FILE_SELECTION (filesel)));
+#endif
         else
 		res = NULL;
 
@@ -745,43 +1030,98 @@ gnome_db_select_file_dialog (GtkWidget *parent, const gchar *title)
 }
 
 /**
- * gnome_db_yes_no_dialog
+ * gnome_db_new_alert
+ * @parent:
+ * @type:
+ * @primary_text:
+ * @secondary_text:
+ *
+ *
+ *
+ * Returns:
  */
-gboolean
-gnome_db_yes_no_dialog (GtkWidget *parent, const gchar *format, ...)
+GtkWidget *
+gnome_db_new_alert (GtkWindow *parent,
+		    GtkMessageType type,
+		    const gchar *primary_text,
+		    const gchar *secondary_text)
 {
-	va_list args;
-        gchar sz[2048];
+	const gchar *stock_id = NULL;
+	gchar *str;
 	GtkWidget *dialog;
-	GdkPixbuf *icon;
-	gboolean retval = FALSE;
+	GtkWidget *image;
+	GtkWidget *label;
+	GtkWidget *hbox;
+	GtkWidget *vbox;
 
-	/* build the message string */
-        va_start (args, format);
-        vsprintf (sz, format, args);
-        va_end (args);
+	g_return_val_if_fail (primary_text != NULL, NULL);
 
-	/* create the dialog */
-	dialog = gtk_message_dialog_new (GTK_WINDOW (parent),
-					 GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION,
-					 GTK_BUTTONS_YES_NO, sz);
-	gtk_window_set_title (GTK_WINDOW (dialog), _("Question"));
+	dialog = gtk_dialog_new_with_buttons ("",
+					     parent,
+					     GTK_DIALOG_DESTROY_WITH_PARENT |
+					     GTK_DIALOG_NO_SEPARATOR |
+					     GTK_DIALOG_MODAL,
+					     NULL);
+					     
+	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+	gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
+	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 12);
 
-	icon = gdk_pixbuf_new_from_file (LIBGNOMEDB_ICONSDIR "/gnome-db.png", NULL);
-	if (icon) {
-		gtk_window_set_icon (GTK_WINDOW (dialog), icon);
-		g_object_unref (icon);
+	hbox = gtk_hbox_new (FALSE, 12);
+	gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox,
+			    TRUE, TRUE, 0);
+
+	switch (type) {
+	case GTK_MESSAGE_INFO:
+		stock_id = GTK_STOCK_DIALOG_INFO;
+		break;
+	case GTK_MESSAGE_WARNING:
+		stock_id = GTK_STOCK_DIALOG_WARNING;
+		break;
+	case GTK_MESSAGE_QUESTION:
+		stock_id = GTK_STOCK_DIALOG_QUESTION;
+		break;
+	case GTK_MESSAGE_ERROR:
+		stock_id = GTK_STOCK_DIALOG_ERROR;
+		break;
+	}
+	g_return_val_if_fail (stock_id != NULL, NULL);
+
+	image = gtk_image_new_from_stock (stock_id,
+					  GTK_ICON_SIZE_DIALOG);
+	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
+	gtk_box_pack_start (GTK_BOX (hbox), image, TRUE, TRUE, 0);
+
+	vbox = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
+
+	label = gtk_label_new (NULL);
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+	str = g_strconcat ("<span weight=\"bold\" size=\"larger\">",
+			   primary_text,
+			   "</span>",
+			   NULL);
+	gtk_label_set_markup (GTK_LABEL (label), str);
+	g_free (str);
+	gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
+
+	if (secondary_text != NULL) {
+		label = gtk_label_new (secondary_text);
+		gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+		gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+		gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
 	}
 
-	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_YES)
-		retval = TRUE;
-	gtk_widget_destroy (dialog);
-
-	return retval;
+	return dialog;
 }
 
 /**
  * gnome_db_show_error
+ * @format:
+ * @...:
+ *
  */
 void
 gnome_db_show_error (const gchar *format, ...)
@@ -792,12 +1132,15 @@ gnome_db_show_error (const gchar *format, ...)
 
 	/* build the message string */
         va_start (args, format);
-        vsprintf (sz, format, args);
+        vsnprintf (sz, sizeof sz, format, args);
         va_end (args);
 
 	/* create the error message dialog */
-	dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR,
-					 GTK_BUTTONS_CLOSE, sz);
+	dialog = gnome_db_new_alert (NULL, GTK_MESSAGE_ERROR, sz, NULL);
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog),
+				      gtk_button_new_from_stock (GTK_STOCK_OK),
+				      GTK_RESPONSE_OK);
+	gtk_widget_show_all (dialog);
 	gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 }
@@ -805,6 +1148,7 @@ gnome_db_show_error (const gchar *format, ...)
 /**
  * gnome_db_show_message
  * @format: Format string.
+ * @...:
  *
  * Displays an information message to the user.
  */
@@ -817,12 +1161,15 @@ gnome_db_show_message (const gchar *format, ...)
 
 	/* build the message string */
         va_start (args, format);
-        vsprintf (sz, format, args);
+        vsnprintf (sz, sizeof sz, format, args);
         va_end (args);
 
-	/* create the error message dialog */
-	dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_INFO,
-					 GTK_BUTTONS_CLOSE, sz);
+	/* create the info message dialog */
+	dialog = gnome_db_new_alert (NULL, GTK_MESSAGE_INFO, sz, NULL);
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog),
+				      gtk_button_new_from_stock (GTK_STOCK_OK),
+				      GTK_RESPONSE_OK);
+	gtk_widget_show_all (dialog);
 	gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 }
@@ -863,3 +1210,39 @@ gnome_db_pop_cursor_busy (GtkWidget *window)
                 g_object_set_data (G_OBJECT (window), "Panel:WindowBusy", GINT_TO_POINTER (busy));
         }
 }
+
+GtkWidget *
+gnome_db_new_check_menu_item (const gchar *label,
+			      gboolean active,
+			      GCallback cb_func,
+			      gpointer user_data)
+{
+	GtkWidget *item;
+	
+	item = gtk_check_menu_item_new_with_mnemonic (label);
+	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item), active);
+	
+	g_signal_connect (G_OBJECT (item), "toggled",
+			  G_CALLBACK (cb_func), user_data);
+
+	return item;
+}
+
+GtkWidget *
+gnome_db_new_menu_item (const gchar *label,
+		 	gboolean pixmap,
+		        GCallback cb_func,
+			gpointer user_data)
+{
+	GtkWidget *item;
+
+	if (pixmap)
+		item = gtk_image_menu_item_new_from_stock (label, NULL);
+	else
+		item = gtk_menu_item_new_with_mnemonic (label);
+	
+	g_signal_connect (G_OBJECT (item), "activate",
+			  G_CALLBACK (cb_func), user_data);
+
+	return item;
+}
